==> icons-vue-0.3.0.tgz: package/lib/watson-health/interactive-segmentation-cursor/16.js <==
'use strict';

var __chunk_1 = require('../../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthInteractiveSegmentationCursor16 = {
  name: 'WatsonHealthInteractiveSegmentationCursor16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = __chunk_1._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M29.4139,24,15.9989,10.5663a2.0473,2.0473,0,0,0-2.8281,0l-2.586,2.586a2.0023,2.0023,0,0,0,0,2.8283L23.9989,29.4145a2.0021,2.0021,0,0,0,2.8281,0l2.5869-2.5865a1.9993,1.9993,0,0,0,0-2.8283Zm-17.415-9.4335,2.5859-2.5859,3.5,3.5L15.498,18.0676l-3.5-3.5ZM25.413,28l-8.5009-8.5188,2.5867-2.587L28,25.4143Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M7.586 18.586H10.414V21.413999999999998H7.586z",
        "transform": "rotate(-45 9 20)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M18.586 7.586H21.413999999999998V10.414H18.586z",
        "transform": "rotate(-45 20 9)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M7.586 7.586H10.414V10.414H7.586z",
        "transform": "rotate(-45 9 9)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthInteractiveSegmentationCursor16;

==> icons-vue-0.6.0.tgz: package/lib/watson-health/interactive-segmentation-cursor/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthInteractiveSegmentationCursor16 = {
  name: 'WatsonHealthInteractiveSegmentationCursor16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M29.4139,24,15.9989,10.5663a2.0473,2.0473,0,0,0-2.8281,0l-2.586,2.586a2.0023,2.0023,0,0,0,0,2.8283L23.9989,29.4145a2.0021,2.0021,0,0,0,2.8281,0l2.5869-2.5865a1.9993,1.9993,0,0,0,0-2.8283Zm-17.415-9.4335,2.5859-2.5859,3.5,3.5L15.498,18.0676l-3.5-3.5ZM25.413,28l-8.5009-8.5188,2.5867-2.587L28,25.4143Z"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2.828",
        "height": "2.828",
        "x": "7.586",
        "y": "18.586",
        "transform": "rotate(-45 9 20)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2.828",
        "height": "2.828",
        "x": "18.586",
        "y": "7.586",
        "transform": "rotate(-45 20 9)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2.828",
        "height": "2.828",
        "x": "7.586",
        "y": "7.586",
        "transform": "rotate(-45 9 9)"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "11 2 2 2 2 11 4 11 4 4 11 4 11 2"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthInteractiveSegmentationCursor16;
